==> owncloud-client-4.0.0.10896-1-armv7h.pkg.tar.xz: usr/lib/cmake/ownCloud/ownCloudConfig-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ownCloud::owncloudResources" for configuration ""
set_property(TARGET ownCloud::owncloudResources APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::owncloudResources PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloudResources.so.4.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloudResources.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::owncloudResources )
list(APPEND _cmake_import_check_files_for_ownCloud::owncloudResources "${_IMPORT_PREFIX}/lib/libowncloudResources.so.4.0.0" )

# Import target "ownCloud::CSync" for configuration ""
set_property(TARGET ownCloud::CSync APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::CSync PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Concurrent"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloud_csync.so.4.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloud_csync.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::CSync )
list(APPEND _cmake_import_check_files_for_ownCloud::CSync "${_IMPORT_PREFIX}/lib/libowncloud_csync.so.4.0.0" )

# Import target "ownCloud::SyncCore" for configuration ""
set_property(TARGET ownCloud::SyncCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::SyncCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "ownCloud::owncloudResources;Qt5::Concurrent;qt5keychain"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloudsync.so.4.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloudsync.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::SyncCore )
list(APPEND _cmake_import_check_files_for_ownCloud::SyncCore "${_IMPORT_PREFIX}/lib/libowncloudsync.so.4.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> owncloud-client-5.0.0.12278-2-armv7h.pkg.tar.xz: usr/lib/cmake/ownCloud/ownCloudConfig-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ownCloud::owncloudResources" for configuration ""
set_property(TARGET ownCloud::owncloudResources APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::owncloudResources PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloudResources.so.5.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloudResources.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::owncloudResources )
list(APPEND _cmake_import_check_files_for_ownCloud::owncloudResources "${_IMPORT_PREFIX}/lib/libowncloudResources.so.5.0.0" )

# Import target "ownCloud::CSync" for configuration ""
set_property(TARGET ownCloud::CSync APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::CSync PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloud_csync.so.5.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloud_csync.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::CSync )
list(APPEND _cmake_import_check_files_for_ownCloud::CSync "${_IMPORT_PREFIX}/lib/libowncloud_csync.so.5.0.0" )

# Import target "ownCloud::SyncCore" for configuration ""
set_property(TARGET ownCloud::SyncCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ownCloud::SyncCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "ownCloud::owncloudResources;qt6keychain"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libowncloudsync.so.5.0.0"
  IMPORTED_SONAME_NOCONFIG "libowncloudsync.so.0"
  )

list(APPEND _cmake_import_check_targets ownCloud::SyncCore )
list(APPEND _cmake_import_check_files_for_ownCloud::SyncCore "${_IMPORT_PREFIX}/lib/libowncloudsync.so.5.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
